@@ -366,7 +366,8 @@ void MarkdownHighlighter::initCodeLangs() {
             {QLatin1String("xml"), MarkdownHighlighter::CodeXML},
             {QLatin1String("yml"), MarkdownHighlighter::CodeYAML},
             {QLatin1String("yaml"), MarkdownHighlighter::CodeYAML},
-            {QLatin1String("forth"), MarkdownHighlighter::CodeForth}};
+            {QLatin1String("forth"), MarkdownHighlighter::CodeForth},
+            {QLatin1String("systemverilog"), MarkdownHighlighter::CodeSystemVerilog}};
 }
 
 /**
@@ -837,6 +838,10 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
             isForth = true;
             loadForthData(types, keywords, builtin, literals, others);
             break;
+        case HighlighterState::CodeSystemVerilog:
+        case HighlighterState::CodeSystemVerilogComment:
+            loadSystemVerilogData(types, keywords, builtin, literals, others);
+            break;
         default:
             setFormat(0, textLen, _formats[CodeBlock]);
             return;
@@ -1896,8 +1901,6 @@ int isInLinkRange(int pos, QVector<QPair<int, int>> &range) {
  * underlines, strikethrough, links, and images.
  */
 void MarkdownHighlighter::highlightInlineRules(const QString &text) {
-    bool isEmStrongDone = false;
-
     // clear existing span ranges for this block
     auto it = _ranges.find(currentBlock().blockNumber());
     if (it != _ranges.end()) {
@@ -1913,14 +1916,12 @@ void MarkdownHighlighter::highlightInlineRules(const QString &text) {
         } else if (currentChar == QLatin1Char('<') &&
                    MH_SUBSTR(i, 4) == QLatin1String("<!--")) {
             i = highlightInlineComment(text, i);
-        } else if (!isEmStrongDone && (currentChar == QLatin1Char('*') ||
-                                       currentChar == QLatin1Char('_'))) {
-            highlightEmAndStrong(text, i);
-            isEmStrongDone = true;
         } else {
             i = highlightLinkOrImage(text, i);
         }
     }
+
+    highlightEmAndStrong(text, 0);
 }
 
 // Helper function for MarkdownHighlighter::highlightLinkOrImage
