@@ -259,8 +259,9 @@ bool mainStartupMisc(const QStringList &arguments) {
     // let the user select another one
     if (!notesPath.isEmpty() && !dir.exists()) {
         if (QMessageBox::question(nullptr, QObject::tr("Note folder not found!"),
-                                  QObject::tr("Your note folder was not found any more! Do you "
-                                              "want to select a new one?")) != QMessageBox::Yes) {
+                                  QObject::tr("Your note folder <b>%1</b> was not found any more! "
+                                              "Do you want to select a new one?")
+                                      .arg(notesPath)) != QMessageBox::Yes) {
             return false;
         }
 
@@ -388,6 +389,8 @@ int main(int argc, char *argv[]) {
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
+    // Help Wayland to find the desktop file for the taskbar icon
+    QGuiApplication::setDesktopFileName(QStringLiteral("PBE.QOwnNotes"));
 
     QString release = RELEASE;
     bool portable = false;
