@@ -216,6 +216,14 @@ void WebSocketServerService::processMessage(const QString &message) {
 
         pSender->sendTextMessage(
             flashMessageJsonText(tr("%n bookmark(s) created", "", bookmarkList.count())));
+
+        // Reload current note if the bookmark was deleted from the current note
+        MainWindow *mainWindow = MainWindow::instance();
+        if (mainWindow != nullptr) {
+            if (getBookmarksNoteName() == mainWindow->getCurrentNote().getName()) {
+                mainWindow->reloadCurrentNoteByNoteId(true);
+            }
+        }
     } else if (type == QLatin1String("switchNoteFolder")) {
 #ifndef INTEGRATION_TESTS
         MainWindow *mainWindow = MainWindow::instance();
@@ -371,10 +379,10 @@ int WebSocketServerService::deleteBookmark(const QJsonObject &jsonObject) {
     // Remove the Markdown text in the current note
     MainWindow *mainWindow = MainWindow::instance();
     if (mainWindow != nullptr) {
-//        auto note = mainWindow->getCurrentNote();
-//        auto textBefore = note.hasEncryptedNoteText() && note.canDecryptNoteText()
-//                           ? note.fetchDecryptedNoteText()
-//                           : note.getNoteText();
+        //        auto note = mainWindow->getCurrentNote();
+        //        auto textBefore = note.hasEncryptedNoteText() && note.canDecryptNoteText()
+        //                           ? note.fetchDecryptedNoteText()
+        //                           : note.getNoteText();
         auto textBefore = mainWindow->activeNoteTextEdit()->toPlainText();
         auto textAfter = textBefore;
         // Remove the bookmark from the note (try "\n" and without "\n")
@@ -382,7 +390,7 @@ int WebSocketServerService::deleteBookmark(const QJsonObject &jsonObject) {
         textAfter.remove(markdown);
 
         if (textBefore != textAfter) {
-//            note.setDecryptedNoteText(textAfter);
+            //            note.setDecryptedNoteText(textAfter);
             mainWindow->allowNoteEditing();
             mainWindow->activeNoteTextEdit()->setPlainText(textAfter);
             noteCount++;
